package Bundle::Locale::CLDR::Northerneurope;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Northerneurope

=head1 CONTENTS

Locale::CLDR::Locales::Cy 0.34.1
Locale::CLDR::Locales::Da 0.34.1
Locale::CLDR::Locales::Et 0.34.1
Locale::CLDR::Locales::Fi 0.34.1
Locale::CLDR::Locales::Fo 0.34.1
Locale::CLDR::Locales::Ga 0.34.1
Locale::CLDR::Locales::Gd 0.34.1
Locale::CLDR::Locales::Gv 0.34.1
Locale::CLDR::Locales::Is 0.34.1
Locale::CLDR::Locales::Kw 0.34.1
Locale::CLDR::Locales::Lt 0.34.1
Locale::CLDR::Locales::Lv 0.34.1
Locale::CLDR::Locales::Nb 0.34.1
Locale::CLDR::Locales::Nn 0.34.1
Locale::CLDR::Locales::Se 0.34.1
Locale::CLDR::Locales::Sv 0.34.1
Locale::CLDR::Locales::Smn 0.34.1
Locale::CLDR::Locales::Cy::Any 0.34.1
Locale::CLDR::Locales::Da::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Et::Any 0.34.1
Locale::CLDR::Locales::Fi::Any 0.34.1
Locale::CLDR::Locales::Fo::Any 0.34.1
Locale::CLDR::Locales::Ga::Any 0.34.1
Locale::CLDR::Locales::Gd::Any 0.34.1
Locale::CLDR::Locales::Gv::Any 0.34.1
Locale::CLDR::Locales::Is::Any 0.34.1
Locale::CLDR::Locales::Kw::Any 0.34.1
Locale::CLDR::Locales::Lt::Any 0.34.1
Locale::CLDR::Locales::Lv::Any 0.34.1
Locale::CLDR::Locales::Nb::Any 0.34.1
Locale::CLDR::Locales::Nn::Any 0.34.1
Locale::CLDR::Locales::Se::Any 0.34.1
Locale::CLDR::Locales::Sv::Any 0.34.1
Locale::CLDR::Locales::Smn::Any 0.34.1
Locale::CLDR::Locales::Cy::Any::Gb 0.34.1
Locale::CLDR::Locales::Da::Any::Dk 0.34.1
Locale::CLDR::Locales::En::Any::Dk 0.34.1
Locale::CLDR::Locales::En::Any::Fi 0.34.1
Locale::CLDR::Locales::En::Any::Gb 0.34.1
Locale::CLDR::Locales::En::Any::Gg 0.34.1
Locale::CLDR::Locales::En::Any::Ie 0.34.1
Locale::CLDR::Locales::En::Any::Im 0.34.1
Locale::CLDR::Locales::En::Any::Je 0.34.1
Locale::CLDR::Locales::En::Any::Se 0.34.1
Locale::CLDR::Locales::Et::Any::Ee 0.34.1
Locale::CLDR::Locales::Fi::Any::Fi 0.34.1
Locale::CLDR::Locales::Fo::Any::Dk 0.34.1
Locale::CLDR::Locales::Fo::Any::Fo 0.34.1
Locale::CLDR::Locales::Ga::Any::Ie 0.34.1
Locale::CLDR::Locales::Gd::Any::Gb 0.34.1
Locale::CLDR::Locales::Gv::Any::Im 0.34.1
Locale::CLDR::Locales::Is::Any::Is 0.34.1
Locale::CLDR::Locales::Kw::Any::Gb 0.34.1
Locale::CLDR::Locales::Lt::Any::Lt 0.34.1
Locale::CLDR::Locales::Lv::Any::Lv 0.34.1
Locale::CLDR::Locales::Nb::Any::No 0.34.1
Locale::CLDR::Locales::Nb::Any::Sj 0.34.1
Locale::CLDR::Locales::Nn::Any::No 0.34.1
Locale::CLDR::Locales::Se::Any::Fi 0.34.1
Locale::CLDR::Locales::Se::Any::No 0.34.1
Locale::CLDR::Locales::Se::Any::Se 0.34.1
Locale::CLDR::Locales::Sv::Any::Ax 0.34.1
Locale::CLDR::Locales::Sv::Any::Fi 0.34.1
Locale::CLDR::Locales::Sv::Any::Se 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::En::Any::150 0.34.1
Locale::CLDR::Locales::Smn::Any::Fi 0.34.1

=cut

1;

